@@ -1,3 +1,5 @@
+"""Helper functions to convert STIX to pandas dataframes."""
+
 import copy
 import datetime
 import re
@@ -9,6 +11,9 @@ from loguru import logger
 from stix2 import Filter, MemoryStore
 from tqdm import tqdm
 
+from mitreattack.constants import MITRE_ATTACK_ID_SOURCE_NAMES
+
+
 # Lookup module for Platforms - each matrix has a list of possible platforms, and each platform with multiple
 #   subplatforms has a corresponding entry. This allows for a pseudo-recursive lookup of subplatforms, as the presence
 #   of a platform at the top level of this lookup indicates the existence of subplatforms.
@@ -75,7 +80,7 @@ def format_date(date):
     """Given a date string, return it formatted as %d %B %Y."""
     if isinstance(date, str):
         date = datetime.datetime.strptime(date, "%Y-%m-%dT%H:%M:%S.%fZ")
-    return "{} {} {}".format(date.strftime("%d"), date.strftime("%B"), date.strftime("%Y"))
+    return f"{date.strftime('%d')} {date.strftime('%B')} {date.strftime('%Y')}"
 
 
 def get_citations(objects):
@@ -106,11 +111,7 @@ def parseBaseStix(sdo):
     row = {}
     url = None
     if sdo.get("external_references"):
-        if sdo["external_references"][0]["source_name"] in [
-            "mitre-attack",
-            "mitre-mobile-attack",
-            "mitre-ics-attack",
-        ]:
+        if sdo["external_references"][0]["source_name"] in MITRE_ATTACK_ID_SOURCE_NAMES:
             row["ID"] = sdo["external_references"][0]["external_id"]
             url = sdo["external_references"][0]["url"]
     if "name" in sdo:
@@ -161,7 +162,9 @@ def techniquesToDf(src, domain):
 
         # sub-technique properties
         if "kill_chain_phases" not in technique:
-            logger.error(f"Skipping {technique['external_references'][0]['external_id']} [{technique['id']}] because it does't have kill chain phases")
+            logger.error(
+                f"Skipping {technique['external_references'][0]['external_id']} [{technique['id']}] because it does't have kill chain phases"
+            )
             continue
         tactic_shortnames = list(map(lambda kcp: kcp["phase_name"], technique["kill_chain_phases"]))
         tactics = list(
@@ -238,7 +241,7 @@ def techniquesToDf(src, domain):
     codex = relationshipsToDf(src, relatedType="technique")
     dataframes.update(codex)
     # add relationship references
-    dataframes["techniques"][f"relationship citations"] = _get_relationship_citations(dataframes["techniques"], codex)
+    dataframes["techniques"]["relationship citations"] = _get_relationship_citations(dataframes["techniques"], codex)
     # add/merge citations
     if not citations.empty:
         if "citations" in dataframes:  # append to existing citations from references
@@ -386,7 +389,7 @@ def softwareToDf(src, domain):
     codex = relationshipsToDf(src, relatedType="software")
     dataframes.update(codex)
     # add relationship references
-    dataframes["software"][f"relationship citations"] = _get_relationship_citations(dataframes["software"], codex)
+    dataframes["software"]["relationship citations"] = _get_relationship_citations(dataframes["software"], codex)
     # add/merge citations
     if not citations.empty:
         if "citations" in dataframes:  # append to existing citations from references
@@ -436,7 +439,7 @@ def groupsToDf(src, domain):
     codex = relationshipsToDf(src, relatedType="group")
     dataframes.update(codex)
     # add relationship references
-    dataframes["groups"][f"relationship citations"] = _get_relationship_citations(dataframes["groups"], codex)
+    dataframes["groups"]["relationship citations"] = _get_relationship_citations(dataframes["groups"], codex)
     # add/merge citations
     if not citations.empty:
         if "citations" in dataframes:  # append to existing citations from references
@@ -513,7 +516,9 @@ class CellRange:
         return "".join(result) + str(row)
 
 
-def build_technique_and_sub_columns(src, techniques, columns, merge_data_handle, matrix_grid_handle, tactic_name):
+def build_technique_and_sub_columns(
+    src, techniques, columns, merge_data_handle, matrix_grid_handle, tactic_name, platform=None
+):
     """Build technique and subtechnique columns for a given matrix and attach them to the appropriate object listings.
 
     :param src: MemoryStore or other stix2 DataSource object holding the domain data
@@ -523,6 +528,8 @@ def build_technique_and_sub_columns(src, techniques, columns, merge_data_handle,
     :param matrix_grid_handle: Handle to the 2D grid array being constructed for the matrix (technique and subtechnique
                                 columns will be appended here)
     :param tactic_name: The name of the corresponding tactic for this column
+    :param platform: [Optional] The name of a platform to filter subtechniques by
+
     :return: Nothing (meta - modifies the passed in merge_data_handle and matrix_grid_handle objects)
     """
     techniques_column = []
@@ -544,6 +551,12 @@ def build_technique_and_sub_columns(src, techniques, columns, merge_data_handle,
             technique_top = len(techniques_column) + 1  # top of row range to merge
             # get sub-techniques
             subtechniques = [src.get(rel["source_ref"]) for rel in subtechnique_ofs]
+            if platform:
+                subtechniques = filter_platforms(
+                    subtechniques,
+                    MATRIX_PLATFORMS_LOOKUP[platform] if platform in MATRIX_PLATFORMS_LOOKUP else [platform],
+                )
+
             subtechniques = remove_revoked_deprecated(subtechniques)
             subtechniques = sorted(subtechniques, key=lambda x: x["name"])
             for i in range(len(subtechniques)):  # for each sub-technique
@@ -627,7 +640,7 @@ def build_parsed_DF_matrix(matrix_grid, columns, merge, parsed_dict):
 
 
 def matricesToDf(src, domain):
-    """Parse STIX matrices from the given data and return parsed matrix structures
+    """Parse STIX matrices from the given data and return parsed matrix structures.
 
     :param src: MemoryStore or other stix2 DataSource object holding the domain data
     :param domain: domain of ATT&CK src corresponds to, e.g "enterprise-attack"
@@ -684,7 +697,14 @@ def matricesToDf(src, domain):
             techniques = remove_revoked_deprecated(techniques)
             techniques = sorted(techniques, key=lambda x: x["name"])
             # add techniques
-            build_technique_and_sub_columns(src, techniques, columns, merge, matrix_grid, tactic["name"])
+            build_technique_and_sub_columns(
+                src=src,
+                techniques=techniques,
+                columns=columns,
+                merge_data_handle=merge,
+                matrix_grid_handle=matrix_grid,
+                tactic_name=tactic["name"],
+            )
 
             for platform in MATRIX_PLATFORMS_LOOKUP[domain]:
                 # In order to support "groups" of platforms, each platform is checked against the lookup a second time.
@@ -692,17 +712,18 @@ def matricesToDf(src, domain):
                 # platform will be.
                 a_techs = filter_platforms(
                     techniques,
-                    [platform] if platform not in MATRIX_PLATFORMS_LOOKUP else MATRIX_PLATFORMS_LOOKUP[platform],
+                    MATRIX_PLATFORMS_LOOKUP[platform] if platform in MATRIX_PLATFORMS_LOOKUP else [platform],
                 )
                 if a_techs:
                     sub_matrices_columns[platform].append(tactic["name"])
                     build_technique_and_sub_columns(
-                        src,
-                        a_techs,
-                        sub_matrices_columns[platform],
-                        sub_matrices_merges[platform],
-                        sub_matrices_grid[platform],
-                        tactic["name"],
+                        src=src,
+                        techniques=a_techs,
+                        columns=sub_matrices_columns[platform],
+                        merge_data_handle=sub_matrices_merges[platform],
+                        matrix_grid_handle=sub_matrices_grid[platform],
+                        tactic_name=tactic["name"],
+                        platform=platform,
                     )
 
         # square the grid because pandas doesn't like jagged columns
@@ -812,11 +833,7 @@ def relationshipsToDf(src, relatedType=None):
             """Add data for one side of the mapping."""
             # logger.debug(sdo)
             if sdo.get("external_references"):
-                if sdo["external_references"][0]["source_name"] in [
-                    "mitre-attack",
-                    "mitre-mobile-attack",
-                    "mitre-ics-attack",
-                ]:
+                if sdo["external_references"][0]["source_name"] in MITRE_ATTACK_ID_SOURCE_NAMES:
                     row[f"{label} ID"] = sdo["external_references"][0]["external_id"]  # "source ID" or "target ID"
             if "name" in sdo:
                 row[f"{label} name"] = sdo["name"]  # "source name" or "target name"
