@@ -1,3 +1,5 @@
+"""Contains Gradient class."""
+
 import colour
 import math
 
@@ -5,13 +7,14 @@ from mitreattack.navlayers.core.exceptions import typeChecker, typeCheckerArray
 
 
 class Gradient:
-    def __init__(self, colors, minValue, maxValue):
-        """
-            Initialization - Creates a gradient object
+    """A Gradient object."""
 
-            :param colors: The array of color codes for this gradient
-            :param minValue: The minValue for this gradient
-            :param maxValue: The maxValue for this gradient
+    def __init__(self, colors, minValue, maxValue):
+        """Initialize - Creates a gradient object.
+
+        :param colors: The array of color codes for this gradient
+        :param minValue: The minValue for this gradient
+        :param maxValue: The maxValue for this gradient
         """
         self.__minValue = None
         self.__maxValue = None
@@ -22,6 +25,7 @@ class Gradient:
 
     @property
     def colors(self):
+        """Getter for colors."""
         return self.__colors
 
     @colors.setter
@@ -34,7 +38,7 @@ class Gradient:
                 colour.Color(entry)
             except AttributeError:
                 self.__alpha.append(entry[-2:])
-                if entry.startswith('#'):
+                if entry.startswith("#"):
                     entry = entry[:7]
                 else:
                     entry = entry[:6]
@@ -43,6 +47,7 @@ class Gradient:
 
     @property
     def minValue(self):
+        """Getter for minValue."""
         return self.__minValue
 
     @minValue.setter
@@ -53,6 +58,7 @@ class Gradient:
 
     @property
     def maxValue(self):
+        """Getter for maxValue."""
         return self.__maxValue
 
     @maxValue.setter
@@ -62,16 +68,14 @@ class Gradient:
         self._compute_curve()
 
     def _compute_curve(self):
-        """
-            Computes the gradient color curve
-        """
+        """Compute the gradient color curve."""
         if self.maxValue is not None and self.minValue is not None and self.colors is not None:
-            chunksize = int(math.floor((self.maxValue - self.minValue)/(len(self.colors) - 1)))
-            fchunksize = int(math.ceil((self.maxValue - self.minValue)/(len(self.colors) - 1)))
+            chunksize = int(math.floor((self.maxValue - self.minValue) / (len(self.colors) - 1)))
+            fchunksize = int(math.ceil((self.maxValue - self.minValue) / (len(self.colors) - 1)))
             self.curve = []
             index = 1
             while index < len(self.colors):
-                s_c = colour.Color(self.colors[index-1])
+                s_c = colour.Color(self.colors[index - 1])
                 e_c = colour.Color(self.colors[index])
                 if index == len(self.colors):
                     curve_2 = list(s_c.range_to(e_c, fchunksize))
@@ -82,10 +86,9 @@ class Gradient:
             self.curve.append(colour.Color(self.colors[-1]))
 
     def compute_color(self, score):
-        """
-            Computes a specific color based on the score value provided
-            :returns: A hexadecimal color representation of the score on
-                the gradient
+        """Compute a specific color based on the score value provided.
+
+        :returns: A hexadecimal color representation of the score on the gradient
         """
         if score <= self.minValue:
             return self.curve[0].hex_l
@@ -96,13 +99,12 @@ class Gradient:
         return target.hex_l
 
     def get_dict(self):
-        """
-            Converts the currently loaded gradient file into a dict
-            :returns: A dict representation of the current gradient object
+        """Convert the currently loaded gradient file into a dict.
+
+        :returns: A dict representation of the current gradient object
         """
         if len(self.__alpha) == len(self.__colors):
             color_out = [f"{self.__colors[i]}{self.__alpha[i]}" for i in range(0, len(self.__alpha))]
         else:
             color_out = self.__colors
-        return dict(colors=color_out, minValue=self.__minValue,
-                    maxValue=self.maxValue)
+        return dict(colors=color_out, minValue=self.__minValue, maxValue=self.maxValue)
